pub struct MinifierReturn {
pub scoping: Option<Scoping>,
pub class_private_mappings: Option<IndexVec<ClassId, FxHashMap<String, CompactStr>>>,
pub property_mangle_cache: Option<ManglePropertyCache>,
pub iterations: u8,
}Fields
scoping: Option<Scoping>class_private_mappings: Option<IndexVec<ClassId, FxHashMap<String, CompactStr>>>A vector where each element corresponds to a class in declaration order. Each element is a mapping from original private member names to their mangled names.
property_mangle_cache: Option<ManglePropertyCache>Updated property-name cache when property mangling ran.
iterations: u8Total number of iterations ran. Useful for debugging performance issues.